==> openshift-model-5.9.0-sources.jar: io/fabric8/openshift/api/model/IdentityBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class IdentityBuilder extends io.fabric8.openshift.api.model.IdentityFluentImpl<io.fabric8.openshift.api.model.IdentityBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.Identity,io.fabric8.openshift.api.model.IdentityBuilder>{
  public IdentityBuilder() {
    this(false);
  }
  public IdentityBuilder(java.lang.Boolean validationEnabled) {
    this(new Identity(), validationEnabled);
  }
  public IdentityBuilder(io.fabric8.openshift.api.model.IdentityFluent<?> fluent) {
    this(fluent, false);
  }
  public IdentityBuilder(io.fabric8.openshift.api.model.IdentityFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new Identity(), validationEnabled);
  }
  public IdentityBuilder(io.fabric8.openshift.api.model.IdentityFluent<?> fluent,io.fabric8.openshift.api.model.Identity instance) {
    this(fluent, instance, false);
  }
  public IdentityBuilder(io.fabric8.openshift.api.model.IdentityFluent<?> fluent,io.fabric8.openshift.api.model.Identity instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withExtra(instance.getExtra()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withProviderName(instance.getProviderName()); 
    fluent.withProviderUserName(instance.getProviderUserName()); 
    fluent.withUser(instance.getUser()); 
    this.validationEnabled = validationEnabled; 
  }
  public IdentityBuilder(io.fabric8.openshift.api.model.Identity instance) {
    this(instance,false);
  }
  public IdentityBuilder(io.fabric8.openshift.api.model.Identity instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withExtra(instance.getExtra()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withProviderName(instance.getProviderName()); 
    this.withProviderUserName(instance.getProviderUserName()); 
    this.withUser(instance.getUser()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.IdentityFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.Identity build() {
    Identity buildable = new Identity(fluent.getApiVersion(),fluent.getExtra(),fluent.getKind(),fluent.getMetadata(),fluent.getProviderName(),fluent.getProviderUserName(),fluent.getUser());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    IdentityBuilder that = (IdentityBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-5.10.2-sources.jar: io/fabric8/openshift/api/model/IdentityBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class IdentityBuilder extends io.fabric8.openshift.api.model.IdentityFluentImpl<io.fabric8.openshift.api.model.IdentityBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.Identity,io.fabric8.openshift.api.model.IdentityBuilder>{
  public IdentityBuilder() {
    this(false);
  }
  public IdentityBuilder(java.lang.Boolean validationEnabled) {
    this(new Identity(), validationEnabled);
  }
  public IdentityBuilder(io.fabric8.openshift.api.model.IdentityFluent<?> fluent) {
    this(fluent, false);
  }
  public IdentityBuilder(io.fabric8.openshift.api.model.IdentityFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new Identity(), validationEnabled);
  }
  public IdentityBuilder(io.fabric8.openshift.api.model.IdentityFluent<?> fluent,io.fabric8.openshift.api.model.Identity instance) {
    this(fluent, instance, false);
  }
  public IdentityBuilder(io.fabric8.openshift.api.model.IdentityFluent<?> fluent,io.fabric8.openshift.api.model.Identity instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withExtra(instance.getExtra()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withProviderName(instance.getProviderName()); 
    fluent.withProviderUserName(instance.getProviderUserName()); 
    fluent.withUser(instance.getUser()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public IdentityBuilder(io.fabric8.openshift.api.model.Identity instance) {
    this(instance,false);
  }
  public IdentityBuilder(io.fabric8.openshift.api.model.Identity instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withExtra(instance.getExtra()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withProviderName(instance.getProviderName()); 
    this.withProviderUserName(instance.getProviderUserName()); 
    this.withUser(instance.getUser()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.IdentityFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.Identity build() {
    Identity buildable = new Identity(fluent.getApiVersion(),fluent.getExtra(),fluent.getKind(),fluent.getMetadata(),fluent.getProviderName(),fluent.getProviderUserName(),fluent.getUser());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    IdentityBuilder that = (IdentityBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
